#
# spec file for package python-langchain-chroma
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-langchain-chroma
Version:        0.1.4
Release:        1.0.2.1.sr20241002
Summary:        An integration package connecting Chroma and LangChain
License:        MIT
URL:            https://github.com/langchain-ai/langchain
Source:         https://files.pythonhosted.org/packages/source/l/langchain-chroma/langchain_chroma-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core >= 1.0.0}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
# langchain-chroma

This package contains the LangChain integration with Chroma.

## Installation

```bash
pip install -U langchain-chroma
```

## Usage

The `Chroma` class exposes the connection to the Chroma vector store.

```python
from langchain_chroma import Chroma

embeddings = ... # use a LangChain Embeddings class

vectorstore = Chroma(embeddings=embeddings)
```

%prep
%autosetup -p1 -n langchain_chroma-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%{python_sitelib}/langchain_chroma
%{python_sitelib}/langchain_chroma-%{version}.dist-info

%changelog
* Wed Oct 23 2024 Dirk Müller <dmueller@suse.com>
- update to 0.1.4:
  * chroma[patch]: Release 0.1.4 (#26470)
  * multiple: pydantic 2 compatibility, v0.3 (#26443)
  * standard-tests[patch]: add Ser/Des test
  * all: Improve make lint command (#25344)
  * chroma: add back fastapi optional dep (#25641)
  * partners/chroma: release 0.1.3 (#25599)
  * chroma: ban chromadb sdk versions 0.5.4 and 0.5.5 due to
    pydantic bug (#25586)
  * [docs]: vector store integration pages (#24858)
  * patch[Partners] Unified fix of incorrect variable declarations
    in all check_imports (#25014)
  * docs: fix kwargs docstring (#25010)
  * all: add release notes to pypi (#24519)
  * partners: add similarity search by image functionality to
    langchain_chroma partner package (#22982)
* Thu Sep  5 2024 Markéta Machová <mmachova@suse.com>
- Initial packaging (v0.1.2), needed by AI stack
